@@ -5,11 +5,11 @@ from sys import stdout
 
 class AuthHandler:
     def login(self, user, mast_pass):
-        connection = sqlite3.Connection("pypass.db")
+        connection = sqlite3.Connection("bin//passman.db")
         cursor = connection.cursor()
         try:
             cursor.execute(
-                f"SELECT username, password from {user} WHERE service='Pypass'"
+                f"SELECT username, password from {user} WHERE service='passman'"
             )
         except Exception as e:
             stdout.write(str("User name or Password does not match"))
@@ -19,3 +19,8 @@ class AuthHandler:
         else:
             stdout.write(str("User name or Password does not match"))
             return False, None, None
+
+
+test = AuthHandler()
+print(test.login("user1", "user1"))
+
