@@ -11,16 +11,16 @@ from tabulate import tabulate
 import pyfiglet
 
 tablefmt = "grid"
-banner = pyfiglet.figlet_format("Pass_man")
+banner = pyfiglet.figlet_format("Pass-man")
 
 
 class Pass_Man(Cmd):
-    prompt = "Pypass> "
+    prompt = "passman> "
     intro = f"{banner}\nWelcome to Pypass press ? to list commands press ctrl+d to exit"
 
     # add new user
     def do_add_user(self, inp):
-        """Add a new user to Pypass"""
+        """Add a new user to Pass-man"""
         stdout.write(
             "add a user name and master password press [y] to continue [n] to exit\n"
         )
@@ -31,7 +31,7 @@ class Pass_Man(Cmd):
             enc_user_name = hash(user_name)
             master_pass = getpass()
             enc_mast_pass = hash(master_pass)
-            connection = sqlite3.connect("pypass.db")
+            connection = sqlite3.connect("bin//passman.db")
             cursor = connection.cursor()
             try:
                 cursor.execute(
@@ -44,7 +44,7 @@ class Pass_Man(Cmd):
                 cursor.execute(
                     f"INSERT INTO {user_name} VALUES (:service,:username,:password)",
                     {
-                        "service": "Pypass",
+                        "service": "passman",
                         "username": enc_user_name,
                         "password": enc_mast_pass,
                     },
@@ -182,6 +182,7 @@ class Pass_Man(Cmd):
             stdout.write("loged out\n")
 
     def do_del_pass(self, inp):
+        """delete password of a service example : del_pass <service name>"""
         stdout.write(str("Enter your user name : "))
         user_name = input()
         master_pass = getpass()
@@ -208,6 +209,7 @@ class Pass_Man(Cmd):
                 crediential = False
 
     def do_del_user(self, inp):
+        """delete user from Pass-man"""
         stdout.write(str("Enter your user name : "))
         user_name = input()
         master_pass = getpass()
@@ -229,6 +231,10 @@ class Pass_Man(Cmd):
                 stderr.write(f"No user named {user_name} exists")
                 crediential = False
 
+    def do_where(self, inp):
+        """return loction of database"""
+        stdout.write(f"{__file__[0:-20]}/bin\n")
+
 
 def main():
     app = Pass_Man()
